Crate crate_activity

Crate crate_activity 

Structs

CrateActivityCli
Crate Activity Analyzer
CrateActivityData
CrateActivitySummary
CrateActivitySummaryBuilder
Builder for CrateActivitySummary.
CrateResponse
CrateUsageSummary
CrateUsageSummaryBuilder
Builder for CrateUsageSummary.
VersionDownload
VersionDownloadBuilder
Builder for VersionDownload.

Enums

CrateActivityError
CrateActivitySummaryBuilderError
Error type for CrateActivitySummaryBuilder
CrateUsageSummaryBuilderError
Error type for CrateUsageSummaryBuilder
Dendrogram
Represents a hierarchical clustering dendrogram node.
DownloadTrend
HierarchicalClusteringError
Errors that can occur during hierarchical clustering.
PcaError
VersionDownloadBuilderError
Error type for VersionDownloadBuilder

Constants

DEFAULT_USER_AGENT
STRONG_CORRELATION_MAGNITUDE

Functions

align_and_normalize_data
analyze_usage
build_correlation_graph
Build a graph of crates where edges represent correlations above or equal to a given threshold.
cache_response
compute_betweenness_centrality
Compute node and edge betweenness centrality using a standard approach: For each node, run a shortest path search and count the shortest paths going through each other node and edge. This is Brandes’ algorithm for betweenness centrality.
compute_degree_centrality
Compute degree centrality: number of edges per node.
compute_pairwise_correlations
compute_time_lag_correlations
configure_directory
crate_activity_main
debug_alignment
debug_correlation
detect_outliers_zscore
display_correlations
display_dendrogram
display_graph_summary
Display graph summary
display_network_communities
Display the communities (connected components) found in the correlation network.
display_time_lag_correlations
display_top_betweenness_nodes
Display betweenness centrality top nodes
display_top_central_nodes
Display the top N nodes by degree centrality.
downweight_outliers
ensure_config_structure
fetch_usage
find_communities
Find communities in the graph by extracting connected components. Each community is a Vec of crate names.
gather_crate_activity_data
girvan_newman_communities
Apply a simplified Girvan–Newman algorithm:
has_significant_variance
intersect_date_ranges
load_cached_response
pearson_correlation
perform_hierarchical_clustering
Perform hierarchical clustering using single-linkage based on crate correlations.
perform_pca
read_crate_list
read_user_agent
remove_outliers