pub struct CrateActivityCli { /* private fields */ }Expand description
Crate Activity Analyzer
Implementations
Sourceimpl CrateActivityCli
impl CrateActivityCli
pub fn ignore_cache(&self) -> &bool
Sourcepub fn all(&self) -> &bool
pub fn all(&self) -> &bool
Enable all analyses: correlations, PCA, hierarchical clustering, network analysis, etc.
Sourcepub fn show_correlations(&self) -> &bool
pub fn show_correlations(&self) -> &bool
Toggle to enable or disable correlation analysis
Sourcepub fn perform_pca(&self) -> &bool
pub fn perform_pca(&self) -> &bool
Toggle to enable or disable PCA analysis
Sourcepub fn perform_hierarchical_clustering(&self) -> &bool
pub fn perform_hierarchical_clustering(&self) -> &bool
Toggle to enable hierarchical clustering
Sourcepub fn correlation_network(&self) -> &bool
pub fn correlation_network(&self) -> &bool
Toggle to enable correlation network analysis
Sourcepub fn network_threshold(&self) -> &f64
pub fn network_threshold(&self) -> &f64
Threshold for including edges in the correlation network graph
Sourcepub fn girvan_newman(&self) -> &Option<usize>
pub fn girvan_newman(&self) -> &Option<usize>
Use Girvan–Newman algorithm to find a specified number of communities
Sourcepub fn compute_betweenness(&self) -> &bool
pub fn compute_betweenness(&self) -> &bool
Compute betweenness centrality for nodes (and edges) and display top nodes
Sourcepub fn print_summary(&self) -> &bool
pub fn print_summary(&self) -> &bool
Print a summary of the network graph
Sourcepub fn time_lag_correlations(&self) -> &bool
pub fn time_lag_correlations(&self) -> &bool
Toggle to enable time-lagged correlation analysis
Sourcepub fn outlier_z_threshold(&self) -> &f64
pub fn outlier_z_threshold(&self) -> &f64
Z-score threshold for outlier detection (MAD-based)
Sourcepub fn downweight_outliers(&self) -> &bool
pub fn downweight_outliers(&self) -> &bool
Downweight outliers instead of removing them
Sourcepub fn outlier_weight(&self) -> &f64
pub fn outlier_weight(&self) -> &f64
Factor by which to downweight outliers if –downweight-outliers is used
pub fn expand_groups(&self) -> &bool
pub fn min_group_size(&self) -> &usize
pub fn verbose(&self) -> &bool
Sourceimpl CrateActivityCli
impl CrateActivityCli
pub fn read_command_line() -> Self
pub fn disable_outlier_handling(&self) -> bool
Sourcepub fn apply_all_flag(&mut self)
pub fn apply_all_flag(&mut self)
Apply the --all flag overrides if set.