Structs
- Crate
Activity Cli - Crate Activity Analyzer
- Crate
Activity Data - Crate
Activity Summary - Crate
Activity Summary Builder - Builder for
CrateActivitySummary. - Crate
Response - Crate
Usage Summary - Crate
Usage Summary Builder - Builder for
CrateUsageSummary. - Version
Download - Version
Download Builder - Builder for
VersionDownload.
Enums
- Crate
Activity Error - Crate
Activity Summary Builder Error - Error type for CrateActivitySummaryBuilder
- Crate
Usage Summary Builder Error - Error type for CrateUsageSummaryBuilder
- Dendrogram
- Represents a hierarchical clustering dendrogram node.
- Download
Trend - Hierarchical
Clustering Error - Errors that can occur during hierarchical clustering.
- PcaError
- Version
Download Builder Error - Error type for VersionDownloadBuilder
Constants
Functions
- align_
and_ normalize_ data - analyze_
usage - build_
correlation_ graph - Build a graph of crates where edges represent correlations above or equal to a given threshold.
- cache_
response - compute_
betweenness_ centrality - Compute node and edge betweenness centrality using a standard approach: For each node, run a shortest path search and count the shortest paths going through each other node and edge. This is Brandes’ algorithm for betweenness centrality.
- compute_
degree_ centrality - Compute degree centrality: number of edges per node.
- compute_
pairwise_ correlations - compute_
time_ lag_ correlations - configure_
directory - crate_
activity_ main - debug_
alignment - debug_
correlation - detect_
outliers_ zscore - display_
correlations - display_
dendrogram - display_
graph_ summary - Display graph summary
- display_
network_ communities - Display the communities (connected components) found in the correlation network.
- display_
time_ lag_ correlations - display_
top_ betweenness_ nodes - Display betweenness centrality top nodes
- display_
top_ central_ nodes - Display the top N nodes by degree centrality.
- downweight_
outliers - ensure_
config_ structure - fetch_
usage - find_
communities - Find communities in the graph by extracting connected components. Each community is a Vec of crate names.
- gather_
crate_ activity_ data - girvan_
newman_ communities - Apply a simplified Girvan–Newman algorithm:
- has_
significant_ variance - intersect_
date_ ranges - load_
cached_ response - pearson_
correlation - perform_
hierarchical_ clustering - Perform hierarchical clustering using single-linkage based on crate correlations.
- perform_
pca - read_
crate_ list - read_
user_ agent - remove_
outliers